@@ -1,7 +1,7 @@
 from celery.task import task
 
 from elasticgit import EG
-from unicore.content.models import Page, Category
+from unicore.content.models import Page, Category, Localisation
 
 
 @task(ignore_result=True, serializer='json')
@@ -10,3 +10,4 @@ def fastforward(repo_path, index_prefix):
     workspace.fast_forward()
     workspace.reindex(Page)
     workspace.reindex(Category)
+    workspace.reindex(Localisation)
